@@ -19,6 +19,7 @@ from .generators.basic import (
     generate_contract_interface_content,
 )
 from .generators.brownie import generate_brownie_interface
+from .version import MOONWORM_VERSION
 
 
 def write_file(content: str, path: str):
@@ -156,6 +157,10 @@ def handle_watch(args: argparse.Namespace) -> None:
             num_confirmations=args.confirmations,
             start_block=args.start,
             end_block=args.end,
+            min_blocks_batch=args.min_blocks_batch,
+            max_blocks_batch=args.max_blocks_batch,
+            batch_size_update_threshold=args.batch_size_update_threshold,
+            only_events=args.only_events,
             outfile=args.outfile,
         )
 
@@ -200,7 +205,13 @@ def handle_find_deployment(args: argparse.Namespace) -> None:
 
 def generate_argument_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(description="Moonworm: Manage your smart contract")
-
+    parser.add_argument(
+        "-v",
+        "--version",
+        action="version",
+        version=f"moonworm {MOONWORM_VERSION}",
+        help="Show version",
+    )
     parser.set_defaults(func=lambda _: parser.print_help())
     subcommands = parser.add_subparsers(dest="subcommands")
 
@@ -265,7 +276,34 @@ def generate_argument_parser() -> argparse.ArgumentParser:
         "--confirmations",
         default=15,
         type=int,
-        help="Number of confirmations to wait for. Default=12",
+        help="Number of confirmations to wait for. Default=15",
+    )
+
+    watch_parser.add_argument(
+        "--min-blocks-batch",
+        default=100,
+        type=int,
+        help="Minimum number of blocks to batch together. Default=100",
+    )
+
+    watch_parser.add_argument(
+        "--max-blocks-batch",
+        default=1000,
+        type=int,
+        help="Maximum number of blocks to batch together. Default=1000",
+    )
+
+    watch_parser.add_argument(
+        "--batch-size-update-threshold",
+        default=100,
+        type=int,
+        help="Number of minimum events  before updating batch size (only for --only-events mode). Default=100",
+    )
+
+    watch_parser.add_argument(
+        "--only-events",
+        action="store_true",
+        help="Only watch events. Default=False",
     )
 
     watch_parser.add_argument(
